@@ -169,17 +169,17 @@ static int set_note(
 
   if (rc && !quiet)
     {
-    fprintf(stderr,"Error setting note attribute for %s - ",
+    fprintf(stderr, "Error setting note attribute for %s - ",
       name);
 
     if ((errmsg = pbs_geterrmsg(con)) != NULL)
       {
-      fprintf(stderr,"%s\n",
+      fprintf(stderr, "%s\n",
         errmsg);
       }
     else
       {
-      fprintf(stderr,"(error %d) %s\n",
+      fprintf(stderr, "(error %d) %s\n",
         pbs_errno,
         pbs_strerror(pbs_errno));
       }
@@ -190,8 +190,6 @@ static int set_note(
 
 
 
-
-
 static void prt_node_attr(
 
   struct batch_status *pbs,         /* I */
@@ -326,11 +324,17 @@ static int marknode(
   }  /* END marknode() */
 
 
-struct batch_status *statnode(int con, char *nodearg)
+
+
+struct batch_status *statnode(
+
+        int   con,
+        char *nodearg)
+
   {
 
   struct batch_status *bstatus;
-  char          *errmsg;
+  char               *errmsg;
 
   bstatus = pbs_statnode(con, nodearg, NULL, NULL);
 
@@ -369,9 +373,13 @@ struct batch_status *statnode(int con, char *nodearg)
   }    /* END statnode() */
 
 
+
+
 void addxmlnode(
-  mxml_t *DE,
+
+  mxml_t              *DE,
   struct batch_status *pbstat)
+
   {
   mxml_t *NE;
   mxml_t *AE;
@@ -404,6 +412,8 @@ void addxmlnode(
 
     MXMLAddE(NE, AE);
     }
+
+  return;
   } /* END addxmlnode() */
 
 
@@ -437,9 +447,11 @@ const char *NState[] =
 
 
 int filterbystate(
-  struct batch_status * pbstat,
-  enum NStateEnum ListType,
-  char *S)
+
+  struct batch_status *pbstat,
+  enum NStateEnum      ListType,
+  char                *S)
+
   {
   int Display;
 
@@ -564,7 +576,7 @@ int main(
 
   progname = strdup(argv[0]);
 
-  while ((i = getopt(argc,argv,"acdlopqrs:x-:N:n")) != EOF)
+  while ((i = getopt(argc, argv, "acdlopqrs:x-:N:n")) != EOF)
     {
     switch (i)
       {
@@ -792,6 +804,7 @@ int main(
   if ((note_flag == set) && (note != NULL))
     {
     /* set the note attrib string on specified nodes */
+
     for (pa = argv + optind;*pa;pa++)
       {
       set_note(con, *pa, note);
