@@ -2072,7 +2072,6 @@ int is_attr(
   int   attr_type)
 
   {
-
   static char *svr_public_attrs[] =
     {
 #include "qmgr_svr_public.h"
@@ -2115,8 +2114,11 @@ int is_attr(
   /* DIAGTODO: need a list of public and read-only diag attrs */
   char **attr_public = NULL;
   char **attr_readonly = NULL;
-  int ret = FALSE;
-  char *name_ptr = NULL, *dupname = NULL;
+
+  char  *dupname  = NULL;
+  char  *name_ptr = NULL;
+
+  int    ret = FALSE;
 
   if (object == MGR_OBJ_SERVER)
     {
@@ -2135,24 +2137,26 @@ int is_attr(
     }
 
   dupname = strdup(name);
-  if(dupname == NULL)
+  if (dupname == NULL)
     {
     return(FALSE);
     }
 
-  name_ptr = strchr(dupname, '.');
-  if(name_ptr)
+  name_ptr = strchr(dupname,'.');
+  if (name_ptr != NULL)
     {
-    *name_ptr = 0;
+    *name_ptr = '\0';
     }
 
   if (attr_public != NULL && (attr_type & TYPE_ATTR_PUBLIC))
     {
     while (*attr_public != NULL && ret == FALSE)
       {
-      /* if (strncmp(name, *attr_public, strlen(*attr_public)) == 0) */
-      if (strcmp(dupname, *attr_public) == 0)
-        ret =  TRUE;
+/*      if (strncmp(name, *attr_public, strlen(*attr_public)) == 0)*/
+      if(strcmp(dupname, *attr_public) == 0)
+        {
+          ret =  TRUE;
+        }
 
       attr_public++;
       }
@@ -2162,7 +2166,7 @@ int is_attr(
     {
     while (*attr_readonly != NULL && ret == FALSE)
       {
-      /* if (strncmp(name, *attr_readonly, strlen(*attr_readonly)) == 0) */
+      /*if (strncmp(name, *attr_readonly, strlen(*attr_readonly)) == 0)*/
       if (strcmp(dupname, *attr_readonly) == 0)
         ret = TRUE;
 
@@ -2170,11 +2174,6 @@ int is_attr(
       }
     }
 
-  if(dupname)
-    {
-    free(dupname);
-    }
-
   return(ret);
   }  /* END is_attr() */
 
