@@ -90,8 +90,16 @@
 #ifndef PBS_JOB_H
 #define PBS_JOB_H 1
 
-/* anything including job.h also needs array.h so lets just include it this way*/
-#include "array.h"
+#ifndef SUCCESS
+#define SUCCESS 1
+#endif 
+#ifndef FAILURE
+#define FAILURE 0
+#endif
+
+#ifndef PBS_MOM
+struct job_array;
+#endif
 
 /*
  * Dependent Job Structures
@@ -129,6 +137,22 @@ struct depend_job
   char dc_svr[PBS_MAXSERVERNAME+1]; /* server owning job  */
   };
 
+struct array_depend
+  {
+  list_link  dp_link;
+  short      dp_type;
+  tlist_head dp_jobs;
+  };
+
+struct array_depend_job
+  {
+  list_link dc_link;
+  /* in this case, the child is the job depending on the array */
+  char dc_child[PBS_MAXSVRJOBID+1];
+  char dc_svr[PBS_MAXSERVERNAME+1];
+  int  dc_num;
+  };
+
 /*
  * Warning: the relation between the numbers assigned to after* and before*
  * is critical.
@@ -144,7 +168,15 @@ struct depend_job
 #define JOB_DEPEND_TYPE_ON   8
 #define JOB_DEPEND_TYPE_SYNCWITH  9
 #define JOB_DEPEND_TYPE_SYNCCT  10
-#define JOB_DEPEND_NUMBER_TYPES  11
+#define JOB_DEPEND_TYPE_AFTERSTARTARRAY 11
+#define JOB_DEPEND_TYPE_AFTEROKARRAY 12
+#define JOB_DEPEND_TYPE_AFTERNOTOKARRAY 13
+#define JOB_DEPEND_TYPE_AFTERANYARRAY 14
+#define JOB_DEPEND_TYPE_BEFORESTARTARRAY 15
+#define JOB_DEPEND_TYPE_BEFOREOKARRAY 16
+#define JOB_DEPEND_TYPE_BEFORENOTOKARRAY 17
+#define JOB_DEPEND_TYPE_BEFOREANYARRAY 18
+#define JOB_DEPEND_NUMBER_TYPES  19
 
 #define JOB_DEPEND_OP_REGISTER  1
 #define JOB_DEPEND_OP_RELEASE  2
@@ -443,6 +475,10 @@ struct job
 
   list_link       ji_alljobs; /* link to next job in server job list */
   list_link       ji_jobque;  /* SVR: link to next job in queue list */
+#ifndef PBS_MOM
+  list_link       ji_jobs_array_sum; /*linked list of jobs with arrays summarized as a single "placeholder" job */
+  list_link       ji_jobque_array_sum;
+#endif
   /* MOM: links to polled jobs */
   time_t  ji_momstat; /* SVR: time of last status from MOM */
   /* MOM: time job suspend (Cray) */
@@ -480,15 +516,24 @@ struct job
   int  ji_lastdest; /* last destin tried by route */
   int  ji_retryok; /* ok to retry, some reject was temp */
   tlist_head ji_rejectdest; /* list of rejected destinations */
-  list_link ji_arrayjobs; /* links to all jobs in same array */
-  job_array      *ji_arraystruct; /* pointer to job_array for this array */
-  int  ji_isparent;    /* set to TRUE if this is a "parent job"*/
+  struct job_array      *ji_arraystruct; /* pointer to job_array for this array */
+  int  ji_is_array_template;    /* set to TRUE if this is a "template job" for a job array*/
+  int  ji_have_nodes_request; /* set to TRUE if node spec uses keyword nodes */
 #endif/* PBS_MOM */   /* END SERVER ONLY */
 
   /*
    * fixed size internal data - maintained via "quick save"
    * some of the items are copies of attributes, if so this
    * internal version takes precendent
+   * 
+   * NOTE: IF YOU MAKE ANY CHANGES TO THIS STRUCT THEN YOU ARE INTRODUCING 
+   * AN INCOMPATIBILITY WITH .JB FILES FROM PREVIOUS VERSIONS OF TORQUE.
+   * YOU SHOULD INCREMENT THE VERSION OF THE STRUCT AND PROVIDE APPROPRIATE 
+   * SUPPORT IN joq_qs_upgrade() FOR UPGRADING PREVIOUS VERSIONS OF THIS 
+   * STRUCT TO THE CURRENT VERSION.  ALSO NOTE THAT ANY CHANGES TO CONSTANTS
+   * THAT DEFINE THE SIZE OF ANY ARRAYS IN THIS STRUCT ALSO INTRODUCE AN 
+   * INCOMPATIBILITY WITH .JB FILES FROM PREVIOUS VERSIONS AND REQUIRE A NEW
+   * STRUCT VERSION AND UPGRADE SUPPORT.
    */
 
   struct jobfix
@@ -645,6 +690,10 @@ typedef struct infoent
 #define TI_FLAGS_INIT           1  /* task has called tm_init */
 #define TI_FLAGS_CHECKPOINT     2  /* task has checkpointed */
 
+#ifdef USESAVEDRESOURCES
+#define TI_FLAGS_RECOVERY       4  /* recovering dead task on restart */
+#endif    /* USESAVEDRESOURCES */
+
 #define TI_STATE_EMBRYO  0
 #define TI_STATE_RUNNING 1    /* includes suspended jobs */
 #define TI_STATE_EXITED  2  /* ti_exitstat valid */
@@ -672,19 +721,19 @@ typedef struct infoent
 
 #define IM_MAX          12
 
-eventent *event_alloc A_((
+eventent *event_alloc(
                            int  command,
                            hnodent *pnode,
                            tm_event_t event,
-                           tm_task_id taskid));
+                           tm_task_id taskid);
 
-task *pbs_task_create A_((
+task *pbs_task_create(
                            job *pjob,
-                           tm_task_id taskid));
+                           tm_task_id taskid);
 
-task *task_find A_((
+task *task_find(
                      job *pjob,
-                     tm_task_id taskid));
+                     tm_task_id taskid);
 
 #endif /* MOM */
 
@@ -734,7 +783,7 @@ task *task_find A_((
 #define JOB_CHECKPOINT_SUFFIX   ".CK"    /* job checkpoint file */
 #define JOB_TASKDIR_SUFFIX      ".TK"    /* job task directory */
 #define JOB_BAD_SUFFIX          ".BD"    /* save bad job file */
-#define JOB_FILE_TMP_SUFFIX     ".TA"    /* temporary job array parent file suffix */
+#define JOB_FILE_TMP_SUFFIX     ".TA"    /* job array template file suffix */
 /*
  * Job states are defined by POSIX as:
  */
@@ -803,6 +852,8 @@ task *task_find A_((
 stdout / stderr files to server spool
 dir so that job can be restarted */
 
+#define JOB_SUBSTATE_ARRAY_TEMP 75  /* job is an array template */
+
 /* decriminator for ji_un union type */
 
 #define JOB_UNION_TYPE_NEW   0
@@ -834,58 +885,61 @@ dir so that job can be restarted */
 #define JOB_EXEC_CMDFAIL  -8 /* exec() of user command failed */
 #define JOB_EXEC_STDOUTFAIL -9 /* could not create/open stdout stderr files */
 
-extern void  add_dest A_((job *));
-extern void  depend_clrrdy A_((job *));
-extern int   depend_on_que A_((attribute *, void *, int));
-extern int   depend_on_exec A_((job *));
-extern int   depend_on_term A_((job *));
-extern job  *find_job A_((char *));
-extern char *get_egroup A_((job *));
-extern char *get_variable A_((job *, char *));
-extern int   init_chkmom A_((job *));
-extern void  issue_track A_((job *));
-extern int   job_abt A_((job **, char *));
+extern void  add_dest(job *);
+extern void  depend_clrrdy(job *);
+extern int   depend_on_que(attribute *, void *, int);
+extern int   depend_on_exec(job *);
+extern int   depend_on_term(job *);
+extern job  *find_job(char *);
+extern char *get_egroup(job *);
+extern char *get_variable(job *, char *);
+extern int   init_chkmom(job *);
+extern void  issue_track(job *);
+extern int   job_abt(job **, char *);
 extern job  *job_alloc();
-extern int   job_unlink_file(job *pjob, const char *name);
-extern job  *job_clone A_((job *, int));
-extern void  job_free A_((job *));
-extern void  job_purge A_((job *));
-extern job  *job_recov A_((char *));
-extern int   job_save A_((job *, int));
-extern int   modify_job_attr A_((job *, svrattrl *, int, int *));
-extern char *prefix_std_file A_((job *, int));
-extern char *add_std_filename A_((job *, char *, int));
-extern int   set_jobexid A_((job *, attribute *, char *));
-extern int   site_check_user_map A_((job *, char *, char *));
-extern void  svr_dequejob A_((job *));
-extern int   svr_enquejob A_((job *));
-extern void  svr_evaljobstate A_((job *, int *, int *, int));
-extern void  svr_mailowner A_((job *, int, int, char *));
-extern void  set_resc_deflt A_((job *, attribute *));
-extern void  set_statechar A_((job *));
-extern int   svr_setjobstate A_((job *, int, int));
+#ifndef PBS_MOM
+extern job  *job_clone(job *,struct job_array *, int);
+#endif
+extern void  job_free(job *);
+extern void  job_purge(job *);
+extern job  *job_recov(char *);
+extern int   job_save(job *, int);
+extern int   modify_job_attr(job *, svrattrl *, int, int *);
+extern char *prefix_std_file(job *, int);
+extern char *add_std_filename(job *, char *, int);
+extern int   set_jobexid(job *, attribute *, char *);
+extern int   site_check_user_map(job *, char *, char *);
+extern void  svr_dequejob(job *);
+extern int   svr_enquejob(job *);
+extern void  svr_evaljobstate(job *, int *, int *, int);
+extern void  svr_mailowner(job *, int, int, char *);
+extern void  set_resc_deflt(job *, attribute *);
+extern void  set_statechar(job *);
+extern int   svr_setjobstate(job *, int, int);
 
 #ifdef BATCH_REQUEST_H
-extern job  *chk_job_request A_((char *, struct batch_request *));
-extern int   net_move A_((job *, struct batch_request *));
-extern int   svr_chk_owner A_((struct batch_request *, job *));
+extern job  *chk_job_request(char *, struct batch_request *);
+extern int   net_move(job *, struct batch_request *);
+extern int   svr_chk_owner(struct batch_request *, job *);
 
-extern struct batch_request *cpy_stage A_((struct batch_request *, job *, enum job_atr, int));
-extern struct batch_request *setup_cpyfiles A_((struct batch_request *, job *, char *, char *, int, int));
-extern struct batch_request *cpy_checkpoint A_((struct batch_request *, job *, enum job_atr, int));
+extern struct batch_request *cpy_stage(struct batch_request *, job *, enum job_atr, int);
+extern struct batch_request *setup_cpyfiles(struct batch_request *, job *, char *, char *, int, int);
+extern struct batch_request *cpy_checkpoint(struct batch_request *, job *, enum job_atr, int);
 #endif /* BATCH_REQUEST_H */
 
 #ifdef QUEUE_H
-extern int   svr_chkque A_((job *, pbs_queue *, char *, int, char *));
-extern int   default_router A_((job *, pbs_queue *, long));
-extern int   site_alt_router A_((job *, pbs_queue *, long));
-extern int   site_acl_check A_((job *, pbs_queue *));
+extern int   count_user_queued_jobs(pbs_queue *,char *);
+extern int   svr_chkque(job *, pbs_queue *, char *, int, char *);
+extern int   default_router(job *, pbs_queue *, long);
+extern int   site_alt_router(job *, pbs_queue *, long);
+extern int   site_acl_check(job *, pbs_queue *);
+extern void  set_chkpt_deflt(job *, pbs_queue *);
 #endif /* QUEUE_H */
 
 #ifdef WORK_TASK_H
-extern void  job_clone_wt A_((struct work_task *));
-extern int   issue_signal A_((job *, char *, void(*)(struct work_task *), void *));
-extern void   on_job_exit A_((struct work_task *));
+extern void  job_clone_wt(struct work_task *);
+extern int   issue_signal(job *, char *, void(*)(struct work_task *), void *);
+extern void   on_job_exit(struct work_task *);
 #endif /* WORK_TASK_H */
 
 #endif /* PBS_JOB_H */
