@@ -123,7 +123,7 @@ enum srv_atr
   SRV_ATR_resource_assn,
   SRV_ATR_resource_cost,
   SRV_ATR_sys_cost,
-  SRV_ATR_schedule_iteration,
+  SRV_ATR_scheduler_iteration,
   SRV_ATR_ping_rate,
   SRV_ATR_check_rate,
   SRV_ATR_tcp_timeout,
@@ -169,10 +169,14 @@ enum srv_atr
   SRV_ATR_display_job_server_suffix,
   SRV_ATR_job_suffix_alias,
   SRV_ATR_MailSubjectFmt,
-  SRV_ATR_MailBodyFmt,           /* 70 */
+  SRV_ATR_MailBodyFmt,
   SRV_ATR_NPDefault,
+  SRV_ATR_clonebatchsize,        /* 70 */
+  SRV_ATR_clonebatchdelay,
   SRV_ATR_JobStartTimeout,
   SRV_ATR_JobForceCancelTime,
+  SRV_ATR_MaxArraySize,
+  SRV_ATR_MaxSlotLimit,
 #include "site_svr_attr_enum.h"
   /* This must be last */
   SRV_ATR_LAST
@@ -236,8 +240,8 @@ extern struct server server;
 
 /* function prototypes */
 
-extern int svr_recov A_((char *, int));
-extern int svr_save A_((struct server *, int));
+extern int svr_recov(char *, int);
+extern int svr_save(struct server *, int);
 
 
 /*
