@@ -76,6 +76,9 @@
 * This license will be governed by the laws of the Commonwealth of Virginia,
 * without reference to its choice of law rules.
 */
+
+#define _DARWIN_UNLIMITED_SELECT
+
 #include <pbs_config.h>   /* the master config generated by configure */
 
 #include <netdb.h>
@@ -98,13 +101,15 @@
 #include <arpa/inet.h>
 
 #if defined(FD_SET_IN_SYS_SELECT_H)
-#  include <sys/select.h>
+#include <sys/select.h>
 #endif
 #if defined(NTOHL_NEEDS_ARPA_INET_H) && defined(HAVE_ARPA_INET_H)
 #include <arpa/inet.h>
 #endif
 
 
+
+
 #include "portability.h"
 #include "server_limits.h"
 #include "net_connect.h"
@@ -115,7 +120,7 @@ extern int LOGLEVEL;
 
 /* External Functions Called */
 
-extern void process_request A_((int));
+extern void process_request(int);
 
 extern time_t time(time_t *);
 
@@ -135,7 +140,7 @@ struct connection svr_conn[PBS_NET_MAX_CONNECTIONS];
 static int max_connection = PBS_NET_MAX_CONNECTIONS;
 static int num_connections = 0;
 static fd_set *GlobalSocketReadSet = NULL;
-static void (*read_func[2]) A_((int));
+static void (*read_func[2])(int);
 
 pbs_net_t pbs_server_addr;
 
@@ -654,7 +659,7 @@ void add_conn(
   pbs_net_t      addr,    /* IP address of connected host */
   unsigned int   port,    /* port number (host order) on connected host */
   unsigned int   socktype, /* inet or unix */
-  void (*func) A_((int)))  /* function to invoke on data rdy to read */
+  void (*func)(int))  /* function to invoke on data rdy to read */
 
   {
   num_connections++;
