@@ -298,9 +298,9 @@ extern char *reqgres(struct rm_attribute *);
 
 char TORQUE_JData[MMAX_LINE];
 
-void state_to_server A_((int, int));
+void state_to_server(int, int);
 
-extern void DIS_rpp_reset A_((void));
+extern void DIS_rpp_reset(void);
 
 /**
  * mom_server_init
@@ -2286,13 +2286,17 @@ void check_state(
 
   static char tmpPBSNodeMsgBuf[1024];
 
-  char *id = "check_state";
-
   if (Force)
     {
     ICount = 0;
     }
 
+  /* clear node state and node messages */
+
+  internal_state &= ~INUSE_DOWN;
+
+  PBSNodeMsgBuf[0] = '\0';
+
   /* conditions:  external state should be down if
      - inadequate file handles available (for period X)
      - external health check fails
@@ -2334,13 +2338,6 @@ void check_state(
 
     if (ICount == 0)
       {
-      /* only clear when we're checking again */
-      /* clear node state and node messages */
-
-      internal_state &= ~INUSE_DOWN;
-
-      PBSNodeMsgBuf[0] = '\0';
-
       if (MUReadPipe(
             PBSNodeCheckPath,
             tmpPBSNodeMsgBuf,
@@ -2380,21 +2377,7 @@ void check_state(
                 proper action may be context sensitive */
 
       if (IsError == 1)
-        {
         internal_state |= INUSE_DOWN;
-
-        snprintf(log_buffer,sizeof(log_buffer),
-          "Setting node to down. The node health script output the following message:\n%s\n",
-          tmpPBSNodeMsgBuf);
-        log_event(PBSEVENT_SYSTEM,PBS_EVENTCLASS_NODE,id,log_buffer);
-        }
-      else
-        {
-        snprintf(log_buffer,sizeof(log_buffer),
-          "Node health script ran and says the node is healthy with this message:\n%s\n",
-          tmpPBSNodeMsgBuf);
-        log_event(PBSEVENT_SYSTEM,PBS_EVENTCLASS_NODE,id,log_buffer);
-        }
       }
     }      /* END if (PBSNodeCheckPath[0] != '\0') */
 
@@ -2524,7 +2507,7 @@ int mom_open_socket_to_jobs_server(
 
   job  *pjob,
   char *caller_id,
-  void (*message_handler) A_((int)))
+  void (*message_handler)(int))
 
   {
   char *svrport = NULL;
@@ -2579,10 +2562,6 @@ int mom_open_socket_to_jobs_server(
       if (pms->SStream != -1)
         {
         addr = rpp_getaddr(pms->SStream);
-        if (addr == NULL)
-        {
-          continue;
-        }
         ipaddr = ntohl(addr->sin_addr.s_addr);
         ipport = ntohs(addr->sin_port);
 
