@@ -178,8 +178,8 @@ static char   rcperr[MAXPATHLEN]; /* file to contain rcp error */
 extern char PBSNodeMsgBuf[1024];
 extern int  LOGLEVEL;
 
-extern int im_compose A_((int, char *, char *, int, tm_event_t, tm_task_id));
-extern int mom_open_socket_to_jobs_server A_((job *, char *, void (*) A_((int))));
+extern int im_compose(int, char *, char *, int, tm_event_t, tm_task_id);
+extern int mom_open_socket_to_jobs_server(job *, char *, void (*)(int));
 
 /* prototypes */
 
@@ -296,6 +296,17 @@ static pid_t fork_to_user(
       return(-PBSE_BADUSER);
       }
 
+#ifdef __CYGWIN__
+    /* printf("TRY IAMADMIN FOR %s ", preq->rq_ind.rq_cpyfile.rq_user); */
+
+    if (IamUser() == 0)
+    {
+      log_err(errno, id, "Can`t run job with Administrator privileges");
+
+      return(-PBSE_BADUSER);
+    }
+#endif  /* __CYGWIN__ */
+
     useruid = pwdp->pw_uid;
 
     if (preq->rq_ind.rq_cpyfile.rq_group[0] == '\0')
@@ -614,11 +625,11 @@ static int return_file(
   filename = std_file_name(pjob, which, &amt); /* amt is place holder */
 
   /* We need to check for NULL which may be returned */
-
+  
   if (filename == NULL)
     {
     return(-1);
-    }
+    }  
 
   if (strcmp(filename, "/dev/null") == 0)
     {
@@ -679,7 +690,7 @@ static int return_file(
   close(fds);
 
   if (remove_file == TRUE && rc == 0)
-    job_unlink_file(pjob, filename);
+    unlink(filename);
 
   return(rc);
   }  /* END return_file() */
@@ -982,7 +993,7 @@ static int is_file_same(
   char *file2)
 
   {
-#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64)
+#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64) && defined(LARGEFILE_WORKS)
 
   struct stat64 sb1, sb2;
 #else
@@ -990,7 +1001,7 @@ static int is_file_same(
   struct stat sb1, sb2;
 #endif
 
-#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64)
+#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64) && defined(LARGEFILE_WORKS)
 
   if ((stat64(file1, &sb1) == 0) && (stat64(file2, &sb2) == 0))
 #else
@@ -1027,7 +1038,7 @@ static int is_file_going_to_dir(
   {
   char           *id = "is_file_going_to_dir";
 
-#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64)
+#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64) && defined(LARGEFILE_WORKS)
 
   struct stat64 sb1;
 #else
@@ -1035,7 +1046,7 @@ static int is_file_going_to_dir(
   struct stat sb1;
 #endif
 
-#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64)
+#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64) && defined(LARGEFILE_WORKS)
 
   if (stat64(destdir, &sb1) == 0)
 #else
@@ -1048,7 +1059,7 @@ static int is_file_going_to_dir(
     int complen = 0;
 
     /* Make sure the destination is a directory */
-
+    
     if (!S_ISDIR(sb1.st_mode))
       {
       /* destination is not a directory */
@@ -1056,21 +1067,21 @@ static int is_file_going_to_dir(
       }
 
     strcpy(filename,file);
-
+    
     /* Does directory match the files path? */
-
+    
     ptr1 = strrchr(filename, '/');
     if (ptr1 != NULL)
       {
       ptr1[0] = '\0';
-
-      complen = strlen(destdir);
+      
+      complen = strlen(destdir);      
       if (destdir[complen - 1] == '/')
         {
         /* don't include trailing slash (if any) in comparision */
         complen--;
         }
-
+      
       if (memcmp(filename, destdir, complen) == 0)
         {
         /* file is going to directory*/
@@ -1422,7 +1433,7 @@ const char *TJobAttr[] =
   "restartname",
   "faulttol",
   "comp_time",
-  "reported",      /* 60 */
+  "reported",       /* 60 */
   "job_type",
   "inter_cmd",
   "proxy_user",
@@ -2185,7 +2196,7 @@ void req_signaljob(
   /*
    * When kill_job is launched, processes are killed and waitpid() should harvest the process
    * and takes action to send an obit. If no matching process exists, then an obit may never be
-   * sent due to the current way that TORQUE's state machine works.
+   * sent due to the current way that TORQUE's state machine works. 
    */
 
   numprocs = kill_job(pjob, sig, id, "killing job");
@@ -2498,7 +2509,7 @@ static int del_files(
   if (path==NULL)
     {
     add_bad_list(pbadfile,"malloc failed",1);
-
+ 
     return(-1);
     }
 
@@ -2507,10 +2518,26 @@ static int del_files(
    * or as user in user homedir.  Let's determine if we will
    * be permitted to run setXid()/setgroup calls.
    */
-  if (getuid() != 0)
+ 
+#ifndef __CYGWIN__
+ if (getuid() != 0)
+    {
+#else
+  if (IamUser() == 1)
+    {
+#endif  /* __CYGWIN__ */
     UID0 = FALSE;
-  if (geteuid() != 0)
+    }
+
+#ifndef __CYGWIN__
+ if (geteuid() != 0)
+    {
+#else
+  if (IamUser() == 1)
+    {
+#endif  /* __CYGWIN__ */
     EUID0 = FALSE;
+    }
 
   /*
    * Build up path of file using local name only, then unlink it.
@@ -2552,10 +2579,10 @@ static int del_files(
           strerror(errno));
 
         add_bad_list(pbadfile,log_buffer,1);
-
+ 
         return(-1);
         }
-
+      
       if (setgid(usergid) != 0 && EUID0 == TRUE)
         {
         snprintf(log_buffer,sizeof(log_buffer),
@@ -2583,7 +2610,7 @@ static int del_files(
 
         return(-1);
       }
-
+	      
       EUID0 = FALSE;
       UID0 = FALSE;
 
@@ -2720,7 +2747,7 @@ static int del_files(
      * path to remove the jobs checkpoint directory not just the checkpoint itself.
      * Do not remove if it is in the remote checkpoint directory list
      */
-
+     
     if (del_dir)
       {
       char *ptr;
@@ -2773,7 +2800,7 @@ static int del_files(
         }
       }
     }
-
+    
 
   return(rc);
   }  /* END del_files() */
@@ -2791,7 +2818,6 @@ void req_rerunjob(
   job  *pjob;
   int        sock;
   int   rc;
-  int   retrycnt = 0;
 
   pjob = find_job(preq->rq_ind.rq_rerun);
 
@@ -2831,17 +2857,10 @@ void req_rerunjob(
    * This is acceptable because we are a child process, not pbs_mom.
    */
 
-retry:
   sock = mom_open_socket_to_jobs_server(pjob, id, NULL);
 
   if (sock < 0)
     {
-    retrycnt++;
-    if (retrycnt < 10)
-      {
-      sleep(1);
-      goto retry;
-      }
     /* FAILURE */
 
     req_reject(PBSE_NOSERVER, 0, preq, NULL, NULL);
@@ -3503,9 +3522,9 @@ void req_cpyfile(
       else if (pair->fp_flag == JOBCKPFILE)
         {
         strncpy(localname, pair->fp_local, sizeof(localname) - 1);  /* from location */
-
+        
         replace_checkpoint_path(localname);
-
+        
         /*
          * If the checkpoint directory
          * is in the the TRemChkptDirList then we do not transfer since directory
@@ -3571,9 +3590,9 @@ void req_cpyfile(
       if (pair->fp_flag == JOBCKPFILE)
         {
         int path_changed = 0;
-
+       
         path_changed = replace_checkpoint_path(arg3);
-
+        
         /*
          * If the checkpoint directory
          * is in the the TRemChkptDirList then we do not transfer since directory
@@ -3583,7 +3602,7 @@ void req_cpyfile(
           {
           continue;
           }
-
+        
         /*
          * We may need to create the directory for this inbound checkpoint /
          * restart file.  If we changed the path and the last segment of the
@@ -3594,22 +3613,22 @@ void req_cpyfile(
           char needdir[MAXPATHLEN + 1];
           int saveumask;
           char *ptr;
-
+          
           strcpy(needdir,arg3);
           ptr = strrchr(needdir,'/');
           if (ptr != NULL)
           {
           ptr[0] = '\0';
           }
-
+          
           saveumask = umask(0000);
 
-          if ((mkdir(needdir, 1777) == -1) && (errno != EEXIST))
+          if ((mkdir(needdir, 0777) == -1) && (errno != EEXIST))
             {
             log_err(errno, id, "Failed to create jobs checkpoint directory");
             }
 
-          umask(saveumask);
+          umask(saveumask); 
           }
         }  /* END if (pair->fp_flag == JOBCKPFILE) */
 
@@ -3680,7 +3699,7 @@ void req_cpyfile(
           wordfree(&arg3exp);
 
           wordexperr = 0;
-
+          
           break; /* Successful */
           }
 
@@ -3879,7 +3898,7 @@ error:
         /* if we are using the default checkpoint path then we need to clean
          * up the job directory
          */
-
+         
         if (strncmp(localname, path_checkpoint, strlen(path_checkpoint)) == 0)
           {
           char *ptr1;
@@ -3899,7 +3918,7 @@ error:
             {
             continue;
             }
-
+          
           if (LOGLEVEL >= 7)
             {
             sprintf(log_buffer,"removing checkpoint file directory (%s)\n", localname);
@@ -3953,6 +3972,8 @@ error:
   if (bad_files)
     {
     reply_text(preq, PBSE_NOCOPYFILE, bad_list);
+
+    log_err(-1,id,bad_list);
     }
   else
     {
