@@ -122,19 +122,19 @@ extern int   LOGLEVEL;
 
 /* Private Functions in this file */
 
-static void post_delete_route A_((struct work_task *));
-static void post_delete_mom1 A_((struct work_task *));
-static void post_delete_mom2 A_((struct work_task *));
-static int forced_jobpurge A_((struct batch_request *));
-static void job_delete_nanny A_((struct work_task *));
-static void post_job_delete_nanny A_((struct work_task *));
-static void purge_completed_jobs A_((struct batch_request *));
+static void post_delete_route(struct work_task *);
+static void post_delete_mom1(struct work_task *);
+static void post_delete_mom2(struct work_task *);
+static int forced_jobpurge(struct batch_request *);
+static void job_delete_nanny(struct work_task *);
+static void post_job_delete_nanny(struct work_task *);
+static void purge_completed_jobs(struct batch_request *);
 
 /* Public Functions in this file */
 
-struct work_task *apply_job_delete_nanny A_((struct job *, int));
-int has_job_delete_nanny A_((struct job *));
-void change_restart_comment_if_needed A_((struct job *));
+struct work_task *apply_job_delete_nanny(struct job *, int);
+int has_job_delete_nanny(struct job *);
+void change_restart_comment_if_needed(struct job *);
 
 /* Private Data Items */
 
@@ -235,6 +235,8 @@ void ensure_deleted(
   } /* ensure_deleted */
 
 
+
+
 /*
  * req_deletejob - service the Delete Job Request
  *
@@ -645,6 +647,20 @@ jump:
       append_link(&pjob->ji_svrtask, &pwtcheck->wt_linkobj, pwtcheck);
     }
 
+  /* make a cleanup task if set */
+  if ((server.sv_attr[SRV_ATR_JobForceCancelTime].at_flags & ATR_VFLAG_SET) &&
+      (server.sv_attr[SRV_ATR_JobForceCancelTime].at_val.at_long > 0))
+    {
+    pwtcheck = set_task(
+        WORK_Timed,
+        time_now + server.sv_attr[SRV_ATR_JobForceCancelTime].at_val.at_long,
+        ensure_deleted,
+        preq);
+    
+    if (pwtcheck != NULL)
+      append_link(&pjob->ji_svrtask, &pwtcheck->wt_linkobj, pwtcheck);
+    }
+
   reply_ack(preq);
 
   return;
@@ -985,6 +1001,12 @@ void remove_job_delete_nanny(
 
   struct work_task *pwtiter, *pwtdel;
 
+  if (pjob->ji_svrtask.ll_next == NULL)
+    {
+    /* no nanny, nothing to delete */
+    return;
+    }
+
   if (pjob->ji_svrtask.ll_next == NULL)
     {
     /* no nanny, nothing to delete */
